==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkImplicitCylinderRepresentation.java <==
// java wrapper for vtkImplicitCylinderRepresentation object
//

package vtk;
import vtk.*;

public class vtkImplicitCylinderRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCenter_2(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_2(id0,id1,id2); }

  private native void SetCenter_3(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_3(id0); }

  private native double[] GetCenter_4();
  public double[] GetCenter()
    { return GetCenter_4(); }

  private native void GetCenter_5(double id0[]);
  public void GetCenter(double id0[])
    { GetCenter_5(id0); }

  private native void SetAxis_6(double id0,double id1,double id2);
  public void SetAxis(double id0,double id1,double id2)
    { SetAxis_6(id0,id1,id2); }

  private native void SetAxis_7(double id0[]);
  public void SetAxis(double id0[])
    { SetAxis_7(id0); }

  private native double[] GetAxis_8();
  public double[] GetAxis()
    { return GetAxis_8(); }

  private native void GetAxis_9(double id0[]);
  public void GetAxis(double id0[])
    { GetAxis_9(id0); }

  private native void SetRadius_10(double id0);
  public void SetRadius(double id0)
    { SetRadius_10(id0); }

  private native double GetRadius_11();
  public double GetRadius()
    { return GetRadius_11(); }

  private native void SetMinRadius_12(double id0);
  public void SetMinRadius(double id0)
    { SetMinRadius_12(id0); }

  private native double GetMinRadiusMinValue_13();
  public double GetMinRadiusMinValue()
    { return GetMinRadiusMinValue_13(); }

  private native double GetMinRadiusMaxValue_14();
  public double GetMinRadiusMaxValue()
    { return GetMinRadiusMaxValue_14(); }

  private native double GetMinRadius_15();
  public double GetMinRadius()
    { return GetMinRadius_15(); }

  private native void SetMaxRadius_16(double id0);
  public void SetMaxRadius(double id0)
    { SetMaxRadius_16(id0); }

  private native double GetMaxRadiusMinValue_17();
  public double GetMaxRadiusMinValue()
    { return GetMaxRadiusMinValue_17(); }

  private native double GetMaxRadiusMaxValue_18();
  public double GetMaxRadiusMaxValue()
    { return GetMaxRadiusMaxValue_18(); }

  private native double GetMaxRadius_19();
  public double GetMaxRadius()
    { return GetMaxRadius_19(); }

  private native void SetAlongXAxis_20(int id0);
  public void SetAlongXAxis(int id0)
    { SetAlongXAxis_20(id0); }

  private native int GetAlongXAxis_21();
  public int GetAlongXAxis()
    { return GetAlongXAxis_21(); }

  private native void AlongXAxisOn_22();
  public void AlongXAxisOn()
    { AlongXAxisOn_22(); }

  private native void AlongXAxisOff_23();
  public void AlongXAxisOff()
    { AlongXAxisOff_23(); }

  private native void SetAlongYAxis_24(int id0);
  public void SetAlongYAxis(int id0)
    { SetAlongYAxis_24(id0); }

  private native int GetAlongYAxis_25();
  public int GetAlongYAxis()
    { return GetAlongYAxis_25(); }

  private native void AlongYAxisOn_26();
  public void AlongYAxisOn()
    { AlongYAxisOn_26(); }

  private native void AlongYAxisOff_27();
  public void AlongYAxisOff()
    { AlongYAxisOff_27(); }

  private native void SetAlongZAxis_28(int id0);
  public void SetAlongZAxis(int id0)
    { SetAlongZAxis_28(id0); }

  private native int GetAlongZAxis_29();
  public int GetAlongZAxis()
    { return GetAlongZAxis_29(); }

  private native void AlongZAxisOn_30();
  public void AlongZAxisOn()
    { AlongZAxisOn_30(); }

  private native void AlongZAxisOff_31();
  public void AlongZAxisOff()
    { AlongZAxisOff_31(); }

  private native void SetDrawCylinder_32(int id0);
  public void SetDrawCylinder(int id0)
    { SetDrawCylinder_32(id0); }

  private native int GetDrawCylinder_33();
  public int GetDrawCylinder()
    { return GetDrawCylinder_33(); }

  private native void DrawCylinderOn_34();
  public void DrawCylinderOn()
    { DrawCylinderOn_34(); }

  private native void DrawCylinderOff_35();
  public void DrawCylinderOff()
    { DrawCylinderOff_35(); }

  private native void SetResolution_36(int id0);
  public void SetResolution(int id0)
    { SetResolution_36(id0); }

  private native int GetResolutionMinValue_37();
  public int GetResolutionMinValue()
    { return GetResolutionMinValue_37(); }

  private native int GetResolutionMaxValue_38();
  public int GetResolutionMaxValue()
    { return GetResolutionMaxValue_38(); }

  private native int GetResolution_39();
  public int GetResolution()
    { return GetResolution_39(); }

  private native void SetTubing_40(int id0);
  public void SetTubing(int id0)
    { SetTubing_40(id0); }

  private native int GetTubing_41();
  public int GetTubing()
    { return GetTubing_41(); }

  private native void TubingOn_42();
  public void TubingOn()
    { TubingOn_42(); }

  private native void TubingOff_43();
  public void TubingOff()
    { TubingOff_43(); }

  private native void SetOutlineTranslation_44(int id0);
  public void SetOutlineTranslation(int id0)
    { SetOutlineTranslation_44(id0); }

  private native int GetOutlineTranslation_45();
  public int GetOutlineTranslation()
    { return GetOutlineTranslation_45(); }

  private native void OutlineTranslationOn_46();
  public void OutlineTranslationOn()
    { OutlineTranslationOn_46(); }

  private native void OutlineTranslationOff_47();
  public void OutlineTranslationOff()
    { OutlineTranslationOff_47(); }

  private native void SetOutsideBounds_48(int id0);
  public void SetOutsideBounds(int id0)
    { SetOutsideBounds_48(id0); }

  private native int GetOutsideBounds_49();
  public int GetOutsideBounds()
    { return GetOutsideBounds_49(); }

  private native void OutsideBoundsOn_50();
  public void OutsideBoundsOn()
    { OutsideBoundsOn_50(); }

  private native void OutsideBoundsOff_51();
  public void OutsideBoundsOff()
    { OutsideBoundsOff_51(); }

  private native void SetWidgetBounds_52(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetWidgetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetWidgetBounds_52(id0,id1,id2,id3,id4,id5); }

  private native void SetWidgetBounds_53(double id0[]);
  public void SetWidgetBounds(double id0[])
    { SetWidgetBounds_53(id0); }

  private native double[] GetWidgetBounds_54();
  public double[] GetWidgetBounds()
    { return GetWidgetBounds_54(); }

  private native void SetConstrainToWidgetBounds_55(int id0);
  public void SetConstrainToWidgetBounds(int id0)
    { SetConstrainToWidgetBounds_55(id0); }

  private native int GetConstrainToWidgetBounds_56();
  public int GetConstrainToWidgetBounds()
    { return GetConstrainToWidgetBounds_56(); }

  private native void ConstrainToWidgetBoundsOn_57();
  public void ConstrainToWidgetBoundsOn()
    { ConstrainToWidgetBoundsOn_57(); }

  private native void ConstrainToWidgetBoundsOff_58();
  public void ConstrainToWidgetBoundsOff()
    { ConstrainToWidgetBoundsOff_58(); }

  private native void SetScaleEnabled_59(int id0);
  public void SetScaleEnabled(int id0)
    { SetScaleEnabled_59(id0); }

  private native int GetScaleEnabled_60();
  public int GetScaleEnabled()
    { return GetScaleEnabled_60(); }

  private native void ScaleEnabledOn_61();
  public void ScaleEnabledOn()
    { ScaleEnabledOn_61(); }

  private native void ScaleEnabledOff_62();
  public void ScaleEnabledOff()
    { ScaleEnabledOff_62(); }

  private native void GetCylinder_63(vtkCylinder id0);
  public void GetCylinder(vtkCylinder id0)
    { GetCylinder_63(id0); }

  private native void GetPolyData_64(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_64(id0); }

  private native void UpdatePlacement_65();
  public void UpdatePlacement()
    { UpdatePlacement_65(); }

  private native long GetAxisProperty_66();
  public vtkProperty GetAxisProperty() {
    long temp = GetAxisProperty_66();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedAxisProperty_67();
  public vtkProperty GetSelectedAxisProperty() {
    long temp = GetSelectedAxisProperty_67();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCylinderProperty_68();
  public vtkProperty GetCylinderProperty() {
    long temp = GetCylinderProperty_68();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedCylinderProperty_69();
  public vtkProperty GetSelectedCylinderProperty() {
    long temp = GetSelectedCylinderProperty_69();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutlineProperty_70();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_70();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedOutlineProperty_71();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_71();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetEdgesProperty_72();
  public vtkProperty GetEdgesProperty() {
    long temp = GetEdgesProperty_72();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetEdgeColor_73(vtkLookupTable id0);
  public void SetEdgeColor(vtkLookupTable id0)
    { SetEdgeColor_73(id0); }

  private native void SetEdgeColor_74(double id0,double id1,double id2);
  public void SetEdgeColor(double id0,double id1,double id2)
    { SetEdgeColor_74(id0,id1,id2); }

  private native void SetEdgeColor_75(double id0[]);
  public void SetEdgeColor(double id0[])
    { SetEdgeColor_75(id0); }

  private native int ComputeInteractionState_76(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_76(id0,id1,id2); }

  private native void PlaceWidget_77(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_77(id0); }

  private native void BuildRepresentation_78();
  public void BuildRepresentation()
    { BuildRepresentation_78(); }

  private native void StartWidgetInteraction_79(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_79(id0); }

  private native void WidgetInteraction_80(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_80(id0); }

  private native void EndWidgetInteraction_81(double id0[]);
  public void EndWidgetInteraction(double id0[])
    { EndWidgetInteraction_81(id0); }

  private native void GetActors_82(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_82(id0); }

  private native void ReleaseGraphicsResources_83(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_83(id0); }

  private native int RenderOpaqueGeometry_84(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_84(id0); }

  private native int RenderTranslucentPolygonalGeometry_85(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_85(id0); }

  private native int HasTranslucentPolygonalGeometry_86();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_86(); }

  private native void SetBumpDistance_87(double id0);
  public void SetBumpDistance(double id0)
    { SetBumpDistance_87(id0); }

  private native double GetBumpDistanceMinValue_88();
  public double GetBumpDistanceMinValue()
    { return GetBumpDistanceMinValue_88(); }

  private native double GetBumpDistanceMaxValue_89();
  public double GetBumpDistanceMaxValue()
    { return GetBumpDistanceMaxValue_89(); }

  private native double GetBumpDistance_90();
  public double GetBumpDistance()
    { return GetBumpDistance_90(); }

  private native void BumpCylinder_91(int id0,double id1);
  public void BumpCylinder(int id0,double id1)
    { BumpCylinder_91(id0,id1); }

  private native void PushCylinder_92(double id0);
  public void PushCylinder(double id0)
    { PushCylinder_92(id0); }

  private native void SetInteractionState_93(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_93(id0); }

  private native int GetInteractionStateMinValue_94();
  public int GetInteractionStateMinValue()
    { return GetInteractionStateMinValue_94(); }

  private native int GetInteractionStateMaxValue_95();
  public int GetInteractionStateMaxValue()
    { return GetInteractionStateMaxValue_95(); }

  private native void SetRepresentationState_96(int id0);
  public void SetRepresentationState(int id0)
    { SetRepresentationState_96(id0); }

  private native int GetRepresentationState_97();
  public int GetRepresentationState()
    { return GetRepresentationState_97(); }

  public vtkImplicitCylinderRepresentation() { super(); }

  public vtkImplicitCylinderRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkImplicitCylinderRepresentation.java <==
// java wrapper for vtkImplicitCylinderRepresentation object
//

package vtk;
import vtk.*;

public class vtkImplicitCylinderRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCenter_2(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_2(id0,id1,id2); }

  private native void SetCenter_3(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_3(id0); }

  private native double[] GetCenter_4();
  public double[] GetCenter()
    { return GetCenter_4(); }

  private native void GetCenter_5(double id0[]);
  public void GetCenter(double id0[])
    { GetCenter_5(id0); }

  private native void SetAxis_6(double id0,double id1,double id2);
  public void SetAxis(double id0,double id1,double id2)
    { SetAxis_6(id0,id1,id2); }

  private native void SetAxis_7(double id0[]);
  public void SetAxis(double id0[])
    { SetAxis_7(id0); }

  private native double[] GetAxis_8();
  public double[] GetAxis()
    { return GetAxis_8(); }

  private native void GetAxis_9(double id0[]);
  public void GetAxis(double id0[])
    { GetAxis_9(id0); }

  private native void SetRadius_10(double id0);
  public void SetRadius(double id0)
    { SetRadius_10(id0); }

  private native double GetRadius_11();
  public double GetRadius()
    { return GetRadius_11(); }

  private native void SetMinRadius_12(double id0);
  public void SetMinRadius(double id0)
    { SetMinRadius_12(id0); }

  private native double GetMinRadiusMinValue_13();
  public double GetMinRadiusMinValue()
    { return GetMinRadiusMinValue_13(); }

  private native double GetMinRadiusMaxValue_14();
  public double GetMinRadiusMaxValue()
    { return GetMinRadiusMaxValue_14(); }

  private native double GetMinRadius_15();
  public double GetMinRadius()
    { return GetMinRadius_15(); }

  private native void SetMaxRadius_16(double id0);
  public void SetMaxRadius(double id0)
    { SetMaxRadius_16(id0); }

  private native double GetMaxRadiusMinValue_17();
  public double GetMaxRadiusMinValue()
    { return GetMaxRadiusMinValue_17(); }

  private native double GetMaxRadiusMaxValue_18();
  public double GetMaxRadiusMaxValue()
    { return GetMaxRadiusMaxValue_18(); }

  private native double GetMaxRadius_19();
  public double GetMaxRadius()
    { return GetMaxRadius_19(); }

  private native void SetAlongXAxis_20(int id0);
  public void SetAlongXAxis(int id0)
    { SetAlongXAxis_20(id0); }

  private native int GetAlongXAxis_21();
  public int GetAlongXAxis()
    { return GetAlongXAxis_21(); }

  private native void AlongXAxisOn_22();
  public void AlongXAxisOn()
    { AlongXAxisOn_22(); }

  private native void AlongXAxisOff_23();
  public void AlongXAxisOff()
    { AlongXAxisOff_23(); }

  private native void SetAlongYAxis_24(int id0);
  public void SetAlongYAxis(int id0)
    { SetAlongYAxis_24(id0); }

  private native int GetAlongYAxis_25();
  public int GetAlongYAxis()
    { return GetAlongYAxis_25(); }

  private native void AlongYAxisOn_26();
  public void AlongYAxisOn()
    { AlongYAxisOn_26(); }

  private native void AlongYAxisOff_27();
  public void AlongYAxisOff()
    { AlongYAxisOff_27(); }

  private native void SetAlongZAxis_28(int id0);
  public void SetAlongZAxis(int id0)
    { SetAlongZAxis_28(id0); }

  private native int GetAlongZAxis_29();
  public int GetAlongZAxis()
    { return GetAlongZAxis_29(); }

  private native void AlongZAxisOn_30();
  public void AlongZAxisOn()
    { AlongZAxisOn_30(); }

  private native void AlongZAxisOff_31();
  public void AlongZAxisOff()
    { AlongZAxisOff_31(); }

  private native void SetDrawCylinder_32(int id0);
  public void SetDrawCylinder(int id0)
    { SetDrawCylinder_32(id0); }

  private native int GetDrawCylinder_33();
  public int GetDrawCylinder()
    { return GetDrawCylinder_33(); }

  private native void DrawCylinderOn_34();
  public void DrawCylinderOn()
    { DrawCylinderOn_34(); }

  private native void DrawCylinderOff_35();
  public void DrawCylinderOff()
    { DrawCylinderOff_35(); }

  private native void SetResolution_36(int id0);
  public void SetResolution(int id0)
    { SetResolution_36(id0); }

  private native int GetResolutionMinValue_37();
  public int GetResolutionMinValue()
    { return GetResolutionMinValue_37(); }

  private native int GetResolutionMaxValue_38();
  public int GetResolutionMaxValue()
    { return GetResolutionMaxValue_38(); }

  private native int GetResolution_39();
  public int GetResolution()
    { return GetResolution_39(); }

  private native void SetTubing_40(int id0);
  public void SetTubing(int id0)
    { SetTubing_40(id0); }

  private native int GetTubing_41();
  public int GetTubing()
    { return GetTubing_41(); }

  private native void TubingOn_42();
  public void TubingOn()
    { TubingOn_42(); }

  private native void TubingOff_43();
  public void TubingOff()
    { TubingOff_43(); }

  private native void SetOutlineTranslation_44(int id0);
  public void SetOutlineTranslation(int id0)
    { SetOutlineTranslation_44(id0); }

  private native int GetOutlineTranslation_45();
  public int GetOutlineTranslation()
    { return GetOutlineTranslation_45(); }

  private native void OutlineTranslationOn_46();
  public void OutlineTranslationOn()
    { OutlineTranslationOn_46(); }

  private native void OutlineTranslationOff_47();
  public void OutlineTranslationOff()
    { OutlineTranslationOff_47(); }

  private native void SetOutsideBounds_48(int id0);
  public void SetOutsideBounds(int id0)
    { SetOutsideBounds_48(id0); }

  private native int GetOutsideBounds_49();
  public int GetOutsideBounds()
    { return GetOutsideBounds_49(); }

  private native void OutsideBoundsOn_50();
  public void OutsideBoundsOn()
    { OutsideBoundsOn_50(); }

  private native void OutsideBoundsOff_51();
  public void OutsideBoundsOff()
    { OutsideBoundsOff_51(); }

  private native void SetWidgetBounds_52(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetWidgetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetWidgetBounds_52(id0,id1,id2,id3,id4,id5); }

  private native void SetWidgetBounds_53(double id0[]);
  public void SetWidgetBounds(double id0[])
    { SetWidgetBounds_53(id0); }

  private native double[] GetWidgetBounds_54();
  public double[] GetWidgetBounds()
    { return GetWidgetBounds_54(); }

  private native void SetConstrainToWidgetBounds_55(int id0);
  public void SetConstrainToWidgetBounds(int id0)
    { SetConstrainToWidgetBounds_55(id0); }

  private native int GetConstrainToWidgetBounds_56();
  public int GetConstrainToWidgetBounds()
    { return GetConstrainToWidgetBounds_56(); }

  private native void ConstrainToWidgetBoundsOn_57();
  public void ConstrainToWidgetBoundsOn()
    { ConstrainToWidgetBoundsOn_57(); }

  private native void ConstrainToWidgetBoundsOff_58();
  public void ConstrainToWidgetBoundsOff()
    { ConstrainToWidgetBoundsOff_58(); }

  private native void SetScaleEnabled_59(int id0);
  public void SetScaleEnabled(int id0)
    { SetScaleEnabled_59(id0); }

  private native int GetScaleEnabled_60();
  public int GetScaleEnabled()
    { return GetScaleEnabled_60(); }

  private native void ScaleEnabledOn_61();
  public void ScaleEnabledOn()
    { ScaleEnabledOn_61(); }

  private native void ScaleEnabledOff_62();
  public void ScaleEnabledOff()
    { ScaleEnabledOff_62(); }

  private native void GetCylinder_63(vtkCylinder id0);
  public void GetCylinder(vtkCylinder id0)
    { GetCylinder_63(id0); }

  private native void GetPolyData_64(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_64(id0); }

  private native void UpdatePlacement_65();
  public void UpdatePlacement()
    { UpdatePlacement_65(); }

  private native long GetAxisProperty_66();
  public vtkProperty GetAxisProperty() {
    long temp = GetAxisProperty_66();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedAxisProperty_67();
  public vtkProperty GetSelectedAxisProperty() {
    long temp = GetSelectedAxisProperty_67();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCylinderProperty_68();
  public vtkProperty GetCylinderProperty() {
    long temp = GetCylinderProperty_68();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedCylinderProperty_69();
  public vtkProperty GetSelectedCylinderProperty() {
    long temp = GetSelectedCylinderProperty_69();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutlineProperty_70();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_70();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedOutlineProperty_71();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_71();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetEdgesProperty_72();
  public vtkProperty GetEdgesProperty() {
    long temp = GetEdgesProperty_72();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetEdgeColor_73(vtkLookupTable id0);
  public void SetEdgeColor(vtkLookupTable id0)
    { SetEdgeColor_73(id0); }

  private native void SetEdgeColor_74(double id0,double id1,double id2);
  public void SetEdgeColor(double id0,double id1,double id2)
    { SetEdgeColor_74(id0,id1,id2); }

  private native void SetEdgeColor_75(double id0[]);
  public void SetEdgeColor(double id0[])
    { SetEdgeColor_75(id0); }

  private native int ComputeInteractionState_76(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_76(id0,id1,id2); }

  private native void PlaceWidget_77(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_77(id0); }

  private native void BuildRepresentation_78();
  public void BuildRepresentation()
    { BuildRepresentation_78(); }

  private native void StartWidgetInteraction_79(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_79(id0); }

  private native void WidgetInteraction_80(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_80(id0); }

  private native void EndWidgetInteraction_81(double id0[]);
  public void EndWidgetInteraction(double id0[])
    { EndWidgetInteraction_81(id0); }

  private native void GetActors_82(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_82(id0); }

  private native void ReleaseGraphicsResources_83(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_83(id0); }

  private native int RenderOpaqueGeometry_84(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_84(id0); }

  private native int RenderTranslucentPolygonalGeometry_85(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_85(id0); }

  private native int HasTranslucentPolygonalGeometry_86();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_86(); }

  private native void SetBumpDistance_87(double id0);
  public void SetBumpDistance(double id0)
    { SetBumpDistance_87(id0); }

  private native double GetBumpDistanceMinValue_88();
  public double GetBumpDistanceMinValue()
    { return GetBumpDistanceMinValue_88(); }

  private native double GetBumpDistanceMaxValue_89();
  public double GetBumpDistanceMaxValue()
    { return GetBumpDistanceMaxValue_89(); }

  private native double GetBumpDistance_90();
  public double GetBumpDistance()
    { return GetBumpDistance_90(); }

  private native void BumpCylinder_91(int id0,double id1);
  public void BumpCylinder(int id0,double id1)
    { BumpCylinder_91(id0,id1); }

  private native void PushCylinder_92(double id0);
  public void PushCylinder(double id0)
    { PushCylinder_92(id0); }

  private native void SetInteractionState_93(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_93(id0); }

  private native int GetInteractionStateMinValue_94();
  public int GetInteractionStateMinValue()
    { return GetInteractionStateMinValue_94(); }

  private native int GetInteractionStateMaxValue_95();
  public int GetInteractionStateMaxValue()
    { return GetInteractionStateMaxValue_95(); }

  private native void SetRepresentationState_96(int id0);
  public void SetRepresentationState(int id0)
    { SetRepresentationState_96(id0); }

  private native int GetRepresentationState_97();
  public int GetRepresentationState()
    { return GetRepresentationState_97(); }

  private native void RegisterPickers_98();
  public void RegisterPickers()
    { RegisterPickers_98(); }

  public vtkImplicitCylinderRepresentation() { super(); }

  public vtkImplicitCylinderRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
